@@ -60,11 +60,24 @@ function __autoload($class_name) {
    require_once $class_name . '.php';
 }
    
-//require_once("CupsPrintIPP.php"); // other files are loaded by it
 
-echo "<html><head></head><body><h1>PHP PrintIPP example</h1>";
+?>
 
-echo "Note that all options are not showed here<br />";
+<html>
+<head>
+<title>PHP PrintIPP test page</title>
+</head>
+<body>
+<h1>PHP PrintIPP test page</h1>
+
+<p>Note that all options are not showed here</p>
+
+
+<a href='#status'>Status of operations</a><br />
+<a href='#completed'>Completed responses from server</a><br />
+<a href='#debug'>debugging informations</a><br />
+
+<?php
 
 //$ipp = new PrintIPP(); // Basic PrintIPP
 //$ipp = new ExtendedPrintIPP(); // extended IPP
@@ -96,6 +109,7 @@ $ipp->setAuthentification($user,$password); // username & password
 $j = 0;
 $test = 1;
 /* getting printer's attributes */
+
 echo "<br /><br /><br />TEST ".$test++."<br />";
 echo "OPERATION  ".$j++."<br />";
 echo "Getting Printer's attributes: ". $ipp->getPrinterAttributes() . "<br />";
@@ -103,6 +117,7 @@ printf('$ipp->status[0] = %s <br /><br />', $ipp->status[0]);
 echo "Printer's attributes :<pre>\n"; print_r($ipp->printer_attributes); echo "</pre>";
 
 /* getting printers (CUPS extention) */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ".$j++."<br />";
@@ -140,10 +155,12 @@ echo "------- END FOR PRINTER $i -------------<br /n>";
 
 
 /* resetting printer uri to those configured */
+
 $ipp->setPrinterURI($printer_uri);
 
 
 /* printing a string */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -156,6 +173,7 @@ echo "Job Attributes:<pre>\n" ; print_r($ipp->job_attributes) ; echo "\n</pre>\n
 $first_job = $ipp->last_job;
 
 /* printing a text file */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
         // HINT: you _must_ supply a charset or set output as raw text
@@ -170,6 +188,7 @@ echo "US ASCII file Job status: ".$ipp->printJob("epson")."<br />";
 
 
 /* printing a document by URI */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -178,6 +197,7 @@ echo "Job Print URI status: ".$ipp->printUri($document_uri)."<br />";
 
 
 /* printing a text file in utf-8 */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -192,8 +212,10 @@ $ipp->setJobName("testfile with UTF-8 characters, gzipped");
 $ipp->setDocumentName("testfile with UTF-8 characters");
 $ipp->setData("./testfiles/test-utf8.txt");//Path to file
 echo "Printing testfile with UTF-8 characters: ".$ipp->printJob()."<br />";
+$ipp->unsetAttribute('orientation-requested');
 
 /* printing a gzipped file */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -204,6 +226,7 @@ $ipp->unsetAttribute('compression');
 
 
 /* getting not-completed jobs */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -214,6 +237,7 @@ echo "Job 0 state-reasons: ".$ipp->jobs_attributes->job_0->job_state_reasons->_v
 echo "<pre>";print_r($ipp->jobs_attributes); echo "</pre>";
 
 /* getting all jobs (subset of attributes) */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -225,6 +249,7 @@ echo "<pre>";print_r($ipp->jobs_attributes); echo "</pre>";
 
 
 /* getting a job's attributes */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -241,6 +266,7 @@ echo "<pre>";print_r($ipp->job_attributes); echo "</pre>";
 
 
 /* printing selected pages from a document */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -255,6 +281,7 @@ $ipp->unsetAttribute('media');
 $ipp->unsetAttribute('number-up');
 
 /* printing a postcript file */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -264,6 +291,7 @@ echo "Printing Postscript Job status: ".$ipp->printJob("epson")."<br />";
 
 
 /* printing a png  file */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -271,6 +299,7 @@ $ipp->setData("./testfiles/test.png");
 echo "Printing png Job status: ".$ipp->printJob("epson")."<br />";
 
 /* printing and cancelling job */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "Printing and Cancelling a job<br />";
@@ -283,6 +312,7 @@ echo "OPERATION ". $j ++ ."<br />";
 echo "Cancel status: ".$ipp->cancelJob($job)."<br />";
 
 /* printing strings, no form feed */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setRawText();
@@ -319,6 +349,7 @@ $ipp->unsetRawText();
 
 
 /* printing a file to see if unsetRawText works */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -327,6 +358,7 @@ echo "Job status (text file after strings): ".$ipp->printJob()."<br />";
 
 
 /* multiple document handling */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setUserName("test");
@@ -356,6 +388,7 @@ echo "Sending document (must be refused): " . $ipp->sendDocument($job,$last=true
 
 
 /* try to validate a job with filetype printer server can't handle */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setMimeMediaType("application/x-foobar");
@@ -372,6 +405,7 @@ echo "Details:<pre>"; print_r($ipp->job_attributes) ; echo "</pre>";
 
 
 /* Printing then holding a job */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -386,6 +420,7 @@ echo "Job State: ".$ipp->job_attributes->job_state->_value0."<br />";
 echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br />";
 
 /* releasing the job */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -397,6 +432,7 @@ echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br
 
 
 /* restarting a job */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 echo "OPERATION ". $j ++ ."<br />";
 echo "Restarting the job $first_job (if completed!): ".$ipp->restartJob($first_job)."<br />";
@@ -407,6 +443,7 @@ echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br
 
 
 /* purging jobs for a printer */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -415,6 +452,7 @@ $ipp->setPrinterURI("ipp://localhost:631/printers/epson"); // Set printer URI he
 echo "Purge-Jobs for printer $printer_uri: ". $ipp->purgeJobs() ."<br />";
 
 /* purging jobs for all printers */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -423,6 +461,7 @@ echo "Purge-Jobs (all printers): ". $ipp->purgeJobs() ."<br />";
 
 
 /* pausing printer */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -434,6 +473,7 @@ echo "Getting printer's attributes: ".$ipp->getPrinterAttributes()."<br />";
 echo "Printer State: ".$ipp->printer_attributes->printer_state->_value0."<br />";
 
 /* Resuming printer */
+
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -481,20 +521,27 @@ echo "<pre>\n";
 print_r($ipp->printers_uri);
 echo "</pre>";
 
-echo "Operations status:\n" ; 
+echo "<a id='status'>Operations status:</a>\n" ; 
 echo "<pre>\n";
 print_r($ipp->status);
 echo "</pre>";
 
+echo "<a id='completed'>Completed responses from server</a>\n";
+echo "<pre>";
+print_r($ipp->response_completed);
+echo "</pre>";
 
 /* get debugging informations */
 
-echo "<h3>Debug</h3><pre>";
+echo "<h3 id='debug'>Debug</h3><pre>";
 $ipp->printDebug();
 echo "</pre>";
 
 
 /* end of test */
 
-echo "END OF TESTFILE</body></html>";
 ?>
+
+<h3>END OF TESTFILE</h3>
+</body>
+</html>
